Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(705)

Unified Diff: include/v8-profiler.h

Issue 1037803002: Return timestamp of the last recorded interval to the caller of HeapProfiler::GetHeapStats (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8-profiler.h
diff --git a/include/v8-profiler.h b/include/v8-profiler.h
index 173849e0cd96a5d8a7c8d9b14359e8e84a56178e..f9439c2e629445c610b226438a21f82b2687b8de 100644
--- a/include/v8-profiler.h
+++ b/include/v8-profiler.h
@@ -471,17 +471,19 @@ class V8_EXPORT HeapProfiler {
* reports updates for all previous time intervals via the OutputStream
* object. Updates on each time interval are provided as a stream of the
* HeapStatsUpdate structure instances.
* The return value of the function is the last seen heap object Id.
*
* StartTrackingHeapObjects must be called before the first call to this
* method.
*/
- SnapshotObjectId GetHeapStats(OutputStream* stream);
+ SnapshotObjectId GetHeapStats(OutputStream* stream,
+ int64_t* timestamp_us = NULL);
/**
* Stops tracking of heap objects population statistics, cleans up all
* collected data. StartHeapObjectsTracking must be called again prior to
- * calling PushHeapObjectsStats next time.
+ * calling GetHeapStats next time.
*/
void StopTrackingHeapObjects();
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -471,17 +471,19 @@ class V8_EXPORT HeapProfiler {
* object. Updates on each time interval are provided as a stream of the
* HeapStatsUpdate structure instances.
- * The return value of the function is the last seen heap object Id.
+ * If |timestamp_us| is supplied, timestamp of the new entry will be written
+ * into it. The return value of the function is the last seen heap object Id.
*
* StartTrackingHeapObjects must be called before the first call to this

Powered by Google App Engine
This is Rietveld 408576698